@@ -1,14 +1,16 @@
-import re
 import hashlib
 import json
+import re
+
 import singer
 
 LOGGER = singer.get_logger()
 
+
 # Convert camelCase to snake_case
 def convert(name):
-    regsub = re.sub('(.)([A-Z][a-z]+)', r'\1_\2', name)
-    return re.sub('([a-z0-9])([A-Z])', r'\1_\2', regsub).lower()
+    regsub = re.sub("(.)([A-Z][a-z]+)", r"\1_\2", name)
+    return re.sub("([a-z0-9])([A-Z])", r"\1_\2", regsub).lower()
 
 
 # Convert keys in json array
@@ -43,8 +45,8 @@ def remove_keys_nodes(this_json, path):
     new_json = this_json
     i = 0
     for record in list(this_json[path]):
-        if record.get('keys', None):
-            new_json[path][i].pop('keys')
+        if record.get("keys", None):
+            new_json[path][i].pop("keys")
         i = i + 1
     return new_json
 
@@ -53,7 +55,7 @@ def remove_keys_nodes(this_json, path):
 def hash_data(data):
     # Prepare the project id hash
     hashId = hashlib.md5()
-    hashId.update(repr(data).encode('utf-8'))
+    hashId.update(repr(data).encode("utf-8"))
     return hashId.hexdigest()
 
 
@@ -64,12 +66,12 @@ def denest_key_fields(this_json, stream_name, path, dimensions_list):
     for record in list(this_json[path]):
         for key in list(record.keys()):
             if isinstance(record[key], list):
-                if key == 'keys':
+                if key == "keys":
                     dim_num = 0
                     # Add dimensions_hash_key for performance_report_custom
-                    if stream_name == 'performance_report_custom':
+                    if stream_name == "performance_report_custom":
                         dims_md5 = str(hash_data(json.dumps(record[key], sort_keys=True)))
-                        new_json[path][i]['dimensions_hash_key'] = dims_md5
+                        new_json[path][i]["dimensions_hash_key"] = dims_md5
                     for dimension in dimensions_list:
                         new_json[path][i][dimension] = record[key][dim_num]
                         dim_num = dim_num + 1
@@ -82,7 +84,7 @@ def add_site_url(this_json, path, site):
     new_json = this_json
     i = 0
     for record in this_json[path]:
-        new_json[path][i]['site_url'] = site
+        new_json[path][i]["site_url"] = site
         i = i + 1
     return new_json
 
@@ -92,7 +94,7 @@ def add_search_type(this_json, path, sub_type):
     new_json = this_json
     i = 0
     for record in this_json[path]:
-        new_json[path][i]['search_type'] = sub_type
+        new_json[path][i]["search_type"] = sub_type
         i = i + 1
     return new_json
 
@@ -111,9 +113,9 @@ def transform_reports(this_json, stream_name, path, site, sub_type, dimensions_l
 #  and stream-specific transforms for sitemaps and performance_reports.
 def transform_json(this_json, stream_name, path, site, sub_type, dimensions_list):
     converted_json = convert_json(this_json)
-    if stream_name == 'sitemaps':
+    if stream_name == "sitemaps":
         new_json = add_site_url(converted_json, path, site)
-    elif stream_name.startswith('performance_report'):
+    elif stream_name.startswith("performance_report"):
         new_json = transform_reports(converted_json, stream_name, path, site, sub_type, dimensions_list)
     else:
         new_json = converted_json
